<?php

namespace Drupal\nextjs\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Next.js Environment entity class.
 *
 * @ConfigEntityType(
 *   id = "nextjs_environment",
 *   label = @Translation("Next.js Environment"),
 *   label_collection = @Translation("Next.js Environments"),
 *   label_singular = @Translation("Next.js Environment"),
 *   label_plural = @Translation("Next.js Environments"),
 *   label_count = @PluralTranslation(
 *     singular = "@count Next.js environment",
 *     plural = "@count Next.js environments",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\nextjs\NextjsEnvironmentListBuilder",
 *     "form" = {
 *       "add" = "Drupal\nextjs\Form\NextjsEnvironmentForm",
 *       "edit" = "Drupal\nextjs\Form\NextjsEnvironmentForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     }
 *   },
 *   config_prefix = "nextjs_environment",
 *   admin_permission = "administer nextjs settings",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *   },
 *   links = {
 *     "collection" = "/admin/config/services/nextjs/environment",
 *     "add-form" = "/admin/config/services/nextjs/environment/add",
 *     "edit-form" = "/admin/config/services/nextjs/environment/{nextjs_environment}/edit",
 *     "delete-form" = "/admin/config/services/nextjs/environment/{nextjs_environment}/delete",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "type",
 *     "host",
 *   }
 * )
 */
class NextjsEnvironment extends ConfigEntityBase implements NextjsEnvironmentInterface {

  /**
   * Entity machine name.
   */
  protected string $id;

  /**
   * Entity label.
   */
  protected string $label;

  /**
   * Environment type.
   */
  protected string $type = 'host';

  /**
   * Host value.
   */
  protected ?string $host = NULL;

  /**
   * {@inheritdoc}
   */
  public function getType(): string {
    return $this->type;
  }

  /**
   * {@inheritdoc}
   */
  public function getHost(): ?string {
    return $this->host;
  }

  /**
   * {@inheritdoc}
   */
  public function getTrimmedHost(): ?string {
    $value = $this->getHost();
    if (!$value) {
      return $value;
    }

    return rtrim($value, '/ \t\n\r\0\x0B');
  }

}
