<?php

namespace Drupal\nextjs\Event;

use Drupal\consumers\Entity\ConsumerInterface;
use Drupal\nextjs\Entity\NextjsEnvironmentInterface;
use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event when a cache webhook is dispatched.
 */
class CacheWebhookEvent extends Event {

  const EVENT_NAME = 'nextjs.cache_webhook';

  /**
   * Whether the request should be aborted.
   */
  protected bool $aborted = FALSE;

  /**
   * Array of hosts to send webhooks to.
   */
  protected array $hosts = [];

  /**
   * Construct new event.
   */
  public function __construct(
    protected ConsumerInterface $consumer,
    protected NextjsEnvironmentInterface $nextjsEnvironment,
    protected array $payload,
    protected string $endpoint,
  ) {}

  /**
   * Get corresponding consumer.
   */
  public function getConsumer(): ConsumerInterface {
    return $this->consumer;
  }

  /**
   * Get corresponding nextjs environment.
   */
  public function getNextjsEnvironment(): NextjsEnvironmentInterface {
    return $this->nextjsEnvironment;
  }

  /**
   * Get event payload.
   */
  public function getPayload(): array {
    return $this->payload;
  }

  /**
   * Set event payload.
   */
  public function setPayload(array $payload) {
    $this->payload = $payload;
  }

  /**
   * Abort the request.
   */
  public function abort() {
    $this->aborted = TRUE;
  }

  /**
   * Whether the event is marked as aborted.
   */
  public function isAborted() {
    return $this->aborted;
  }

  /**
   * Add a host.
   */
  public function addHost(string $host) {
    $this->hosts[] = [
      'uri' => $host,
    ];
  }

  /**
   * Set array of hosts.
   */
  public function setHosts(array $hosts) {
    $this->hosts = $hosts;
  }

  /**
   * Get the hosts.
   */
  public function getHosts(): array {
    return $this->hosts;
  }

  /**
   * Set the endpoint.
   */
  public function setEndpoint(string $endpoint) {
    $this->endpoint = $endpoint;
  }

  /**
   * Get the endpoint.
   */
  public function getEndpoint(): string {
    return $this->endpoint;
  }

}
