<?php

namespace Drupal\nextjs\EventSubscriber;

use Drupal\nextjs\Event\CacheWebhookEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscribe to cache webhook events.
 */
class CacheWebhookEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      CacheWebhookEvent::EVENT_NAME => [
        ['handleWebhookEvent'],
      ],
    ];
  }

  /**
   * Handle webhook event.
   *
   * When the Next.js environment is of type host,
   * sets the correct host on the event.
   */
  public function handleWebhookEvent(CacheWebhookEvent $event) {
    $environment = $event->getNextjsEnvironment();

    if ($environment->getType() === "host") {
      $host = $environment->getHost();

      if (!$host) {
        throw new \Exception('Next.js environment of type host does not have host set!');
      }

      $event->addHost($host);
    }
  }

}
